@@ -227,10 +227,11 @@ class Screen(SignalEvent):
             change_with = props.get('selection_change_with')
             if change_with:
                 selection = RPCExecute('model', self.model_name,
-                    props['selection'], dict((p, None) for p in change_with))
+                                       props['selection'],
+                                       dict((p, None) for p in change_with))
             else:
                 selection = RPCExecute('model', self.model_name,
-                    props['selection'])
+                                       props['selection'])
         except RPCException:
             selection = []
         selection.sort(key=itemgetter(1))
@@ -277,7 +278,8 @@ class Screen(SignalEvent):
         while True:
             try:
                 ids = RPCExecute('model', self.model_name, 'search', domain,
-                    self.offset, self.limit, self.order, context=context)
+                                 self.offset, self.limit, self.order,
+                                 context=context)
             except RPCException:
                 break
             if ids or self.offset <= 0:
@@ -287,7 +289,8 @@ class Screen(SignalEvent):
             if self.limit is not None and len(ids) == self.limit:
                 try:
                     self.search_count = RPCExecute('model', self.model_name,
-                        'search_count', domain, context=context)
+                                                   'search_count',
+                                                   domain, context=context)
                 except RPCException:
                     self.search_count = 0
             else:
@@ -354,8 +357,8 @@ class Screen(SignalEvent):
             domain = ['AND', domain, screen_domain]
             set_tab_counter(lambda: None, idx)
             RPCExecute('model', self.model_name,
-                'search_count', domain, context=self.context,
-                callback=functools.partial(set_tab_counter, idx=idx))
+                       'search_count', domain, context=self.context,
+                       callback=functools.partial(set_tab_counter, idx=idx))
 
     @property
     def context(self):
@@ -395,9 +398,9 @@ class Screen(SignalEvent):
             self.current_record = None
         self.__group.signal_connect(self, 'group-cleared', self._group_cleared)
         self.__group.signal_connect(self, 'group-list-changed',
-                self._group_list_changed)
+                                    self._group_list_changed)
         self.__group.signal_connect(self, 'record-modified',
-            self._record_modified)
+                                    self._record_modified)
         self.__group.signal_connect(self, 'group-changed', self._group_changed)
         self.__group.add_fields(fields)
         for name, views in fields_views.items():
@@ -409,7 +412,7 @@ class Screen(SignalEvent):
     def new_group(self, context=None):
         context = context if context is not None else self.context
         self.group = Group(self.model_name, {}, domain=self.domain,
-            context=context, readonly=self.readonly)
+                           context=context, readonly=self.readonly)
 
     def _group_cleared(self, group, signal):
         for view in self.views:
@@ -446,7 +449,8 @@ class Screen(SignalEvent):
         else:
             pos = 0
         self.signal('record-message', (pos, len(self.group) + self.offset,
-            self.search_count, record and record.id))
+                                       self.search_count,
+                                       record and record.id))
         self.signal('resources', record.resources if record else None)
         # update resources after 1 second
         GLib.timeout_add(1000, self._update_resources, record)
@@ -522,7 +526,7 @@ class Screen(SignalEvent):
                 break
             else:
                 self.__current_view = ((self.__current_view + 1)
-                        % len(self.views))
+                                       % len(self.views))
             if not view_type and view_id is None:
                 break
             if view_type and not view_id and not len(self.view_to_load):
@@ -549,7 +553,7 @@ class Screen(SignalEvent):
         else:
             try:
                 view = RPCExecute('model', self.model_name, 'fields_view_get',
-                    view_id, view_type, context=self.context)
+                                  view_id, view_type, context=self.context)
             except RPCException:
                 return
         return self.add_view(view)
@@ -640,12 +644,12 @@ class Screen(SignalEvent):
         path = self.current_record.get_path(self.group)
         if self.current_view.view_type == 'tree':
             # False value must be not saved
-            saved = all((x is 0 or x > 0 for x in self.group.save()))
+            saved = all((x is not False and x > 0 for x in self.group.save()))
             record_id = self.current_record.id if self.current_record else None
         elif self.current_record.validate(fields):
             record_id = self.current_record.save(force_reload=True)
             # False value must be not saved
-            saved = record_id is 0 or record_id > 0
+            saved = record_id is not False and record_id > 0
         else:
             self.set_cursor()
             self.current_view.display()
@@ -710,7 +714,7 @@ class Screen(SignalEvent):
             self.group.unremove(record)
 
     def remove(self, delete=False, remove=False, force_remove=False,
-            records=None):
+               records=None):
         records = records or self.selected_records
         if not records:
             return
@@ -730,7 +734,7 @@ class Screen(SignalEvent):
             # to save the previous_model as it can be already deleted.
             self.current_record = None
             record.group.remove(record, remove=remove, signal=False,
-                force_remove=force_remove)
+                                force_remove=force_remove)
         # send record-changed only once
         record.signal('record-changed')
 
@@ -762,7 +766,7 @@ class Screen(SignalEvent):
         ids = [r.id for r in self.selected_records]
         try:
             new_ids = RPCExecute('model', self.model_name, 'copy', ids, {},
-                context=self.context)
+                                 context=self.context)
         except RPCException:
             return False
         self.load(new_ids)
@@ -790,10 +794,11 @@ class Screen(SignalEvent):
         if state is None and CONFIG['client.save_tree_state']:
             json_domain = self.get_tree_domain(parent)
             try:
-                expanded_nodes, selected_nodes = RPCExecute('model',
-                    'ir.ui.view_tree_state', 'get',
-                    self.model_name, json_domain,
-                    view.children_field)
+                expanded_nodes, selected_nodes = \
+                    RPCExecute('model',
+                               'ir.ui.view_tree_state', 'get',
+                               self.model_name, json_domain,
+                               view.children_field)
                 expanded_nodes = json.loads(expanded_nodes)
                 selected_nodes = json.loads(selected_nodes)
             except RPCException:
@@ -853,9 +858,9 @@ class Screen(SignalEvent):
                         selected_paths, separators=(',', ':'))
                     try:
                         RPCExecute('model', 'ir.ui.view_tree_state', 'set',
-                            self.model_name, json_domain, view.children_field,
-                            json_paths, json_selected_path,
-                            process_exception=False)
+                                   self.model_name, json_domain,
+                                   view.children_field, json_paths,
+                                   json_selected_path, process_exception=False)
                         clear_cache('model.ir.ui.view_tree_state.get')
                     except Exception:
                         logger.warn(
@@ -896,7 +901,7 @@ class Screen(SignalEvent):
                 self.current_record = None
         if self.views:
             self.search_active(self.current_view.view_type
-                in ('tree', 'graph', 'calendar'))
+                               in ('tree', 'graph', 'calendar'))
             for view in self.views:
                 # Always display tree view to update model
                 # because view can be used even if it is not shown
@@ -907,8 +912,8 @@ class Screen(SignalEvent):
                     view.display()
             self.current_view.widget.set_sensitive(
                 bool(self.group
-                    or (self.current_view.view_type != 'form')
-                    or self.current_record))
+                     or (self.current_view.view_type != 'form')
+                     or self.current_record))
             if set_cursor:
                 self.set_cursor(reset_view=False)
         self.set_tree_state()
@@ -1146,7 +1151,7 @@ class Screen(SignalEvent):
         values = record._get_on_change_args(args)
         try:
             changes = RPCExecute('model', self.model_name, button['name'],
-                values, context=self.context)
+                                 values, context=self.context)
         except RPCException:
             return
         record.set_on_change(changes)
@@ -1160,7 +1165,7 @@ class Screen(SignalEvent):
             context['_timestamp'].update(record.get_timestamp())
         try:
             action = RPCExecute('model', self.model_name, button['name'],
-                ids, context=context)
+                                ids, context=context)
         except RPCException:
             action = None
         self.reload(ids, written=True)
@@ -1181,7 +1186,7 @@ class Screen(SignalEvent):
         elif action == 'delete':
             if access['delete']:
                 self.remove(delete=not self.parent,
-                    force_remove=not self.parent)
+                            force_remove=not self.parent)
         elif action == 'remove':
             if access['write'] and access['read'] and self.parent:
                 self.remove(remove=True)
@@ -1247,5 +1252,5 @@ class Screen(SignalEvent):
                         view_ids, separators=(',', ':'))))
         query_string = urllib.parse.urlencode(query_string)
         return urllib.parse.urlunparse(('tryton',
-                CONFIG['login.host'],
-                '/'.join(path), query_string, '', ''))
+                                        CONFIG['login.host'],
+                                        '/'.join(path), query_string, '', ''))
